﻿using System;
using System.ComponentModel;
using System.Data;
using System.Windows.Forms;
using System.Drawing;
using LevelEditor;

namespace LevelEditorControls
{
    class TileSheetPictureBox : PictureBox
    {
        int mouseX, mouseY;
        int selectedTileIndex = -1;

        public Map MapParent
        {
            get;
            set;
        }

        public int TileIndex
        {
            get
            {
                if (MapParent != null)
                    return (mouseX / MapParent.TileWidth)
                        + (mouseY / MapParent.TileHeight) * MapParent.MapWidth;
                else
                    return -1;
            }
        }

        public int SelectedTileIndex
        {
            get
            {
                if (Image == null)
                    return -1;
                else
                    return selectedTileIndex;
            }
            set { selectedTileIndex = value; }
        }

        public Rectangle SelectedTileRectangle
        {
            get
            {
                int x = (SelectedTileIndex % MapParent.MapWidth) * MapParent.TileWidth;
                int y = (SelectedTileIndex / MapParent.MapHeight) * MapParent.TileHeight;
                return new Rectangle(x, y, MapParent.TileWidth, MapParent.TileHeight);
            }
        }

        public TileSheetPictureBox()
        {
        }

        protected override void OnPaint(PaintEventArgs pe)
        {
            base.OnPaint(pe);

            if (MapParent != null)
            {
                pe.Graphics.FillRectangle(new SolidBrush(Color.FromArgb(128, 255, 255, 255)),
                    SelectedTileRectangle);
                pe.Graphics.DrawRectangle(Pens.Black, SelectedTileRectangle);
            }
        }

        protected override void OnMouseMove(MouseEventArgs e)
        {
            mouseX = e.X;
            mouseY = e.Y;
            base.OnMouseMove(e);
            this.Invalidate();
        }

        protected override void OnClick(EventArgs e)
        {
            base.OnClick(e);
            this.SelectedTileIndex = this.TileIndex;
        }
    }
}